{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit dmSystem;

interface

uses
  SysUtils, Classes, Dialogs, IB_Components, IB_Session, IB_Header,
  klSettings;

type
  TdaSystem = class(TDataModule)
    cnTedalo: TIB_Connection;
    tnMain: TIB_Transaction;
    dsqlMeasures: TIB_DSQL;
    procedure DataModuleCreate(Sender: TObject);
  private
    fSettings: TSettings;
    fLoggList: TStrings;
    { Private declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent; Settings: TSettings; ALoggList: TStrings); overload;
    destructor Destroy; override;
    procedure Connect();
    procedure Disconnect();
    procedure addToLogg(sMsg: string);
    property LoggList: TStrings read fLoggList write fLoggList;
end;

var
  daSystem: TdaSystem;

implementation

{$R *.dfm}

constructor TdaSystem.Create(AOwner: TComponent; Settings: TSettings; ALoggList: TStrings);
begin
  inherited Create(AOwner);
  fSettings := Settings;
  fLoggList := ALoggList;
end;

destructor TdaSystem.Destroy;
begin
  inherited;
end;


procedure TdaSystem.addToLogg(sMsg: string);
begin
  if Assigned(LoggList) then begin
    LoggList.Add(sMsg);
  end;
end;

procedure TdaSystem.DataModuleCreate(Sender: TObject);
begin
  cnTedalo.LoginPrompt := False;
  cnTedalo.Connected := False;
  cnTedalo.Params.Clear; // clearing it in case there are some parameters like 'RESERVE PAGE SPACE=TRUE' and 'FORCED WRITES=TRUE'. Some versions of Firebird demands SYSDBA grants for setting these.
  cnTedalo.CharSet  := 'ISO8859_1';
  cnTedalo.Protocol := cpTCP_IP;
  cnTedalo.Server   := fSettings.DB_Server;
  cnTedalo.Path     := fSettings.DB_Path + '\Tedalo.fdb';
  cnTedalo.Username := 'SYSDBA';
  cnTedalo.Password := 'masterkey';
end;

procedure TdaSystem.Connect;
var
  sMsg: string;
begin
  try
    cnTedalo.Connect;
    addToLogg('Connected to database.');
  except
    on E: EIB_ISCError do begin
      case e.ERRCODE of
        isc_network_error: begin
          sMsg := 'Network error. No Connection to server "' + cnTedalo.Server + ' on port 3050';
          addToLogg(sMsg);
          ShowMessage(sMsg);
        end;
        isc_login: begin
          sMsg := 'Wrong username or password.';
          addToLogg(sMsg);
          ShowMessage(sMsg);
        end;
        isc_io_error: begin
          sMsg := 'Error! Can''t find database: ' + cnTedalo.DatabaseName;
          addToLogg(sMsg);
          MessageDlg(sMsg, mtError, [mbOK], 0);
        end;
      end;
    end;
    on E: Exception do begin
      ShowMessage('Error on dmSystem.Connect: ' + E.Message);
    end;
  end;
end;

procedure TdaSystem.Disconnect;
begin
  cnTedalo.Disconnect;
  addToLogg('Disconnected from database');
end;

end.
