{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit klJob;

interface

uses
  Classes,
  klSettings;

type
  T_Job = class(TObject)
  private
    fNr: string;
    fActive: Boolean;
    fGSMType: string;
    fTOA5FileName: string;
    fChannelList: TStringList;
    fVDVSiteName: string;
  public
    constructor Create(Settings: TSettings; JobNr: String);
    destructor Destroy ; Override;
    property Nr: string read fNr;       // The mobile phone number is the Job number.
    property Active: Boolean read fActive;
    property GSMType: string read fGSMType;
    property TOA5FileName: string read fTOA5FileName;
    property ChannelList: TStringList read fChannelList;
    property VDVSiteName: string read fVDVSiteName;
  end;

implementation

uses
  utLog;

{-------------------------------------------------------------------------------
 T_Job
-------------------------------------------------------------------------------}
constructor T_Job.Create(Settings: TSettings; JobNr: String);
var
  idx: Integer;
begin
  inherited Create;
  fActive := False;
  if Settings.JobsList.Find(JobNr, idx) then begin
    fNr       := JobNr;
    fActive   := Settings.JobIsActive(JobNr);
    fGSMType  := Settings.getJobGSMType(JobNr);
    fTOA5FileName:= Settings.getJobTOA5FileName(JobNr);
    fChannelList := Settings.getJobGSMChannelList(fGSMType);
    fVDVSiteName := Settings.getVDVSiteName(JobNr);
  end else begin
    Write2Log('Warning: The job ' + JobNr + ' is not defined in the ini file.');
  end;
end;

destructor T_Job.Destroy;
begin
  if Assigned(fChannelList) then begin
    fChannelList.Free;
  end;
  inherited Destroy;
end;

end.
