{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit klMatrix;

interface

uses
  Classes;

type
  T_Mess = Class(TObject)
  private
    f_ch : Integer;   // ch Channel
    f_val : Double;   // val Value
    function get_ch() : Integer;
    procedure set_ch(n_ch :Integer);
    function get_val() : Double;
    procedure set_val(n_val :Double);
  public
    constructor Create;
    destructor Destroy; override;
    property _ch : Integer read get_ch write set_ch;
    property _val : Double read get_val write set_val;
  end;

  T_Zeile = Class(TObject)
  public
    f_ch_list : TStringList;   // jede Zeile hat eine ChannelListe
    f_time    : TDateTime;
    constructor Create;
    destructor Destroy ; Override;
    property time : TDateTime Read f_time Write f_time;
  end;

  T_Matrix = class(TObject)
  private
    fTimeList: TStringList;
    procedure cleanTimeList;
    function findTimeIndex(t: TDateTime): Integer;
  public
    constructor Create;
    destructor Destroy ; Override;
    procedure addMValue(ch: Integer; val:Double; time: TDateTime);
    property TimeList: TStringList read fTimeList write fTimeList;
  end;

implementation

uses
  SysUtils;
  
{-------------------------------------------------------------------------------
 T_Mess
-------------------------------------------------------------------------------}
constructor T_Mess.Create;
begin
  inherited Create;
  f_ch  := 0;
  f_val := 0;
end;

 destructor T_Mess.Destroy;
begin
  inherited Destroy;
end;

function T_Mess.get_ch() : Integer;
begin
  result := f_ch;
end;

procedure T_Mess.set_ch(n_ch :Integer);
begin
  f_ch := n_ch;
end;

function T_Mess.get_val() : Double;
begin
  result := f_val;
end;

procedure T_Mess.set_val(n_val :Double);
begin
  f_val := n_val;
end;


{-------------------------------------------------------------------------------
 T_Zeile
-------------------------------------------------------------------------------}
constructor T_Zeile.Create;
begin
  inherited Create;
  f_ch_list := TStringList.Create;
end;

destructor T_Zeile.Destroy ;
var i : Integer;
begin
  for i := 0 to f_ch_list.Count - 1 do
    f_ch_list.Objects[i].Free;
  f_ch_list.Clear;
  f_ch_list.Free;
  f_ch_list := nil;
  inherited Destroy;
end;


{-------------------------------------------------------------------------------
 T_Matrix
-------------------------------------------------------------------------------}
constructor T_Matrix.Create;
begin
  inherited Create;
  fTimeList := TStringList.Create;
end;

procedure T_Matrix.cleanTimeList;
var
 i,j : Integer;
 A_Zeile : T_Zeile;
begin
  for i := 0 to fTimeList.Count - 1 do begin
    A_Zeile := T_Zeile(fTimeList.Objects[i]);
    for j := 0 to A_Zeile.f_ch_list.Count-1 do
      A_Zeile.f_ch_list.Objects[j].Free;
    A_Zeile.f_ch_list.Clear;
    fTimeList.Objects[i].Free;
   end;
  fTimeList.Clear;
end;

destructor T_Matrix.Destroy;
begin
  cleanTimeList;
  fTimeList.Free;
  inherited Destroy;
end;

function T_Matrix.findTimeIndex(t: TDateTime): Integer;
var
  i : Integer;
  ans : Integer;
  A_Zeile : T_Zeile;
begin
  ans := -1;
  for i := 0 to fTimeList.Count - 1 do begin
    A_Zeile := T_Zeile(fTimeList.Objects[i]);
    if t = A_Zeile.time then begin
       ans := i;
       Break;
    end;
  end;
  Result := ans;
end;

procedure T_Matrix.addMValue(ch: Integer; val: Double; time: TDateTime);
var
  A_mess : T_mess;
  A_Zeile: T_Zeile;
  t : TDateTime;
  hour,minute,second,ms : Word;
  idx : Integer;
begin
  DecodeTime(time,hour,minute,second,ms);
  t := EncodeTime(hour,minute,second,0);
  t := t + Trunc(time);
  idx := findTimeIndex(t);
  if idx = -1 then begin
    A_mess       := T_mess.Create;
    A_Mess._ch   := ch;
    A_Mess._val  := val;
    A_Zeile      := T_Zeile.Create;
    A_zeile.time := t;
    A_Zeile.f_ch_list.AddObject(IntToStr(ch), A_Mess);
    fTimeList.AddObject(FloatToStr(t), A_Zeile);
  end else begin
    A_Zeile := T_Zeile(fTimeList.Objects[idx]);
    A_mess  := T_mess.create;
    A_Mess._ch := ch;
    A_Mess._val := val;
    A_Zeile.f_ch_list.AddObject(IntToStr(ch), A_Mess);
  end;
end;

end.
