{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit klParse;

interface

uses
  Classes;

type
  T_Parser = Class(TObject)
  private
  public
    constructor Create;
    destructor Destroy; override;
    function cleanText(str: WideString) : WideString;
    function getCommands(str: WideString) : TStringList;
    function getVariables(cmd: WideString) : TStringList;
    function getValues(cmd: WideString) : TStringList;
    function DM_processing_time(str : WideString) : WideString;
    function Mail_time(str : WideString) : WideString;
  end;

implementation

uses HTTPUtil, SysUtils;
  
{-------------------------------------------------------------------------------
 T_Parser
-------------------------------------------------------------------------------}
constructor T_Parser.Create;
begin
  inherited Create;
end;

destructor T_Parser.Destroy;
begin
  inherited Destroy;
end;

function T_Parser.cleanText(str: WideString) : WideString;
var
  st : WideString;
  len : integer;
  i: Integer;
begin
  len := length(str);
  for i := 1 to len do begin
    if ((ord(str[i])>31) and (ord(str[i])<255)) then
      st := st + str[i];
  end;
  Result := st;
end;

function T_Parser.getCommands(str: WideString) : TStringList;
var
  st : IStringTokenizer;
  cmds : TStringList;
begin
  cmds := TStringList.Create();

  st := HTTPUtil.StringTokenizer(str,'#');
  while (st.hasMoreTokens()) do
    cmds.Add(st.nextToken());

  result := cmds;
end;

function T_Parser.getVariables(cmd: WideString) : TStringList;
var
  st : IStringTokenizer;
  vars : TStringList;
begin
  vars := TStringList.Create();

  st := HTTPUtil.StringTokenizer(cmd,'/');
  while (st.hasMoreTokens()) do
    vars.Add(st.nextToken());

  Result := vars;
end;

function T_Parser.getValues(cmd: WideString) : TStringList;
var
  res : TStringList;
  epos : integer;
begin
  res := TStringList.Create();
  epos := AnsiPos('=',cmd);
  if (epos>0) then begin
    res.Add(copy(cmd, 1, epos-1));
    res.Add(copy(cmd, epos+1, length(cmd)-epos));
  end;
  Result := res;
end;


function T_Parser.DM_processing_time(str : WideString) : WideString;
var
  temp : Widestring;
  d : TDateTime;
begin
  //24.08.2010 11:04:59	Mail	Debug	6 Master f
  temp := Copy(str,1,Pos(#9,str)-1);
  try
    d := StrToDateTime(temp)
  except
    on E:Exception do Begin
      temp := '-1';
    end;
  end;
  Result:=temp;
end;

function T_Parser.Mail_time(str : WideString) : WideString;
var
  temp : Widestring;
  d : TDateTime;
begin
  //(sent: UTC 24.08.2010 7:01:12)
  temp := Copy(str,Pos('UTC',str)+3,Length(str));
  temp := Copy(temp,1,Pos(')',temp)-1);
  try
    d := StrToDateTime(temp)
  except
    on E:Exception do Begin
      temp := '-1';
    end;
  end;
  Result:=temp;
end;

end.
