{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit utDate;

interface

function GetTimeZoneBias: TDateTime;
function UTCToTime(UTC:TDateTime):TDateTime;

implementation

uses
  Windows, Timezones;

function GetTimeZoneBias: TDateTime;
const
   MINUTES_PER_DAY = 24.0 * 60.0;
var
  tzi : TTimeZoneInformation;
begin
   case GetTimeZoneInformation(tzi) of
      TIME_ZONE_ID_STANDARD:
         result := (tzi.Bias) / MINUTES_PER_DAY;

      TIME_ZONE_ID_DAYLIGHT: // Summertime
         Result := (tzi.Bias+tzi.DaylightBias) / MINUTES_PER_DAY;
   else
      Result := 0.0;
   end;
end;


function UTCToTime(UTC:TDateTime):TDateTime;
// takes care of summer and stardard time
var
  tz_info : TTimeZoneInformation;
begin
  GetTimeZoneInformation(tz_info);
  result := UTCToTZLocalTime(tz_info, UTC);
end;


end.
