{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit utFileOps;

interface

uses
  Classes;

function GetFileTimes(const FileName: string; var Created: TDateTime; var Accessed: TDateTime; var Modified: TDateTime): Boolean;

implementation

uses
  Windows, SysUtils, DateUtils;


function GetFileTimes(const FileName: string; var Created: TDateTime; var Accessed: TDateTime; var Modified: TDateTime): Boolean;
var
  h: THandle;
  Info1, Info2, Info3: TFileTime;
  SysTimeStruct: SYSTEMTIME;
  TimeZoneInfo: TTimeZoneInformation;
  Bias: Double;
begin
  Result := False;
  Bias := 0;
  h := FileOpen(FileName, fmOpenRead or fmShareDenyNone);
  if h > 0 then begin
    try
      if GetTimeZoneInformation(TimeZoneInfo) <> $FFFFFFFF then
        Bias := TimeZoneInfo.Bias / 1440; // 60x24
      GetFileTime(h, @Info1, @Info2, @Info3);
      if FileTimeToSystemTime(Info1, SysTimeStruct) then
        Created := SystemTimeToDateTime(SysTimeStruct) - Bias;
      if FileTimeToSystemTime(Info2, SysTimeStruct) then
        Accessed := SystemTimeToDateTime(SysTimeStruct) - Bias;
      if FileTimeToSystemTime(Info3, SysTimeStruct) then begin
        Modified := SystemTimeToDateTime(SysTimeStruct) - Bias;
        Modified := RecodeSecond(Modified,0);
        Modified := RecodeMilliSecond(Modified, 0);
      end;
      Result := True;
    finally
      FileClose(h);
    end;
  end;
end;



end.
