{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit utLog;

interface

uses SysUtils, Dialogs, Forms, Classes, TypInfo;

procedure AppException(Sender: TObject; E: Exception);
procedure Write2Log(sMsg: String);
procedure Write2LogEx(sMsg: String; sListe: TStringList);
procedure logFormActions(pClassInfo: Pointer; sAction: String);

const
  LOGFILENAME = '_Tedalo.log';

implementation


procedure AppException(Sender: TObject; E: Exception);
var strError: string;
begin
  strError := 'Es ist folgender Fehler aufgetreten:' + #10#13#10#13 + E.Message + #10#13 + 'Fehlertyp: ' + E.ClassName + #10#13 + 'Sender: ' + Sender.ClassName;
  Messagedlg(strError,mterror,[mbok],0);
end;


procedure Write2Log(sMsg: String);
var
  Present: TDateTime;
  Year, Month, Day, Hour, Min, Sec, MSec: Word;
  sYear, sMonth, sDay, sHour, sMin, sSec, sTimeStamp: String;
  f_log: TextFile;
  path, filename: String;
begin
  Present:= Now;
  DecodeDate(Present, Year, Month, Day);
  DecodeTime(Present, Hour, Min, Sec, MSec);
  // Datum in Strings umwandeln
  sYear := IntToStr(CurrentYear); // Aufjedenfall 4-stellig
  if Month < 10 then
    sMonth := '0' + IntToStr(Month)
  else
    sMonth := IntToStr(Month);
  if Day < 10 then
    sDay := '0' + IntToStr(Day)
  else
    sDay := IntToStr(Day);
  if Hour < 10 then
    sHour := '0' + IntToStr(Hour)
  else
    sHour := IntToStr(Hour);
  if Min < 10 then
    sMin := '0' + IntToStr(Min)
  else
    sMin := IntToStr(Min);
  if Sec < 10 then
    sSec := '0' + IntToStr(Sec)
  else
    sSec := IntToStr(Sec);


  sTimeStamp := sYear + sMonth + sDay + '_' + sHour + ':' + sMin + ':' + sSec;

  path := ExtractFilePath(Application.ExeName) + 'log\';
  CreateDir(path);
  filename := ExtractFilePath(Application.ExeName) + 'log\' + sYear + sMonth + sDay + LOGFILENAME;
  Try
    AssignFile(f_log, filename);
    if FileExists(filename) then
      Append(f_log)
    else
      ReWrite(f_log);
    WriteLn(f_log, sTimeStamp + ': ' + sMsg);
    Flush(f_log);
    CloseFile(f_log);
  Except
    // if it is not possible to write to the logfile, continue run the program
  end;
end;


procedure Write2LogEx(sMsg: String; sListe: TStringList);
var
  Present: TDateTime;
  Year, Month, Day, Hour, Min, Sec, MSec: Word;
  sYear, sMonth, sDay, sTimeStamp, s: String;
  f_log: TextFile;
  filename: String;
  i: Integer;
begin
  Present:= Now;
  DecodeDate(Present, Year, Month, Day);
  DecodeTime(Present, Hour, Min, Sec, MSec);
  // Datum in Strings umwandeln
  sYear := IntToStr(CurrentYear); // Aufjedenfall 4-stellig
  if Month < 10 then begin
    sMonth := '0' + IntToStr(Month)
  end else begin
    sMonth := IntToStr(Month);
  end;

  if Day < 10 then begin
    sDay := '0' + IntToStr(Day)
  end else begin
    sDay := IntToStr(Day);
  end;
  sTimeStamp := sYear + sMonth + sDay + '_' + IntToStr(Hour) + ':' + IntToStr(Min);

  filename := ExtractFilePath(Application.ExeName) + 'log\' + sYear + sMonth + sDay + LOGFILENAME;
  AssignFile(f_log, filename);
  if FileExists(filename) then begin
    Append(f_log)
  end else begin
    ReWrite(f_log);
  end;

  WriteLn(f_log, sTimeStamp + ': ' + sMsg);

  for i := 0 to sListe.Count - 1 do begin
    s := sListe[i];
    s := StringReplace(s, #13#10, #13#10 + '                  ', [rfReplaceAll]);
    s := '##             ' + IntToStr(i) + ': ' + s;
    WriteLn(f_log, s);
  end;

  Flush(f_log);
  CloseFile(f_log);
end;

procedure logFormActions(pClassInfo: Pointer; sAction: String);
var
  TD: PTypeData;
begin
  TD := GetTypeData(pClassInfo);
  if TD <> nil then
    Write2Log(TD^.UnitName + ' *** ' + sAction + ' ***');
end;


end.

