{
    This file is part of Tedalo.

    Tedalo converts data sent from Keller GSM-2/ARC-1 to TOA5 file format.

    Copyright (C) 2011-2020  Corax Solution AB.

    Tedalo is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Tedalo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tedalo.  If not, see <http://www.gnu.org/licenses/>.

    Note that Tedalo depends on other software, with different licensing
    conditions.

    For more information, contact Jrg Schiemann, josc@corax.nu
}

unit utTCPIP;

interface

function GetIPAddress(name: String): string;
function IsIPAddress(sIPAddress: string): boolean;

implementation

uses
 Winsock;

const
  WINSOCK_VERSION = $0101;

function GetIPAddress(name: String): string;
const WSVer = $101;
var
  wsaData: TWSAData;
  P: PHostEnt;
begin
  Result := '';
  if WSAStartup(WSVer, wsaData) = 0 then begin
   begin
      P := GetHostByName(PChar(name));
      if P <> nil then Result := iNet_ntoa(PInAddr(p^.h_addr_list^)^);
    end;
    WSACleanup;
  end;
end;

function IsIPAddress(sIPAddress: string): boolean;
var
  ipLengthOfGroup, ipPosition, ipNoOfGroups: integer;
  ipGroupNum, Code: integer;
begin
  IsIpAddress := False;
  ipNoOfGroups := 0;
  ipLengthOfGroup := 0;
  for ipPosition := 1 to Length(sIPAddress) do
    case Ord(sIPAddress[ipPosition]) of
      48..57:
        begin
          inc(ipLengthOfGroup);
          if (ipLengthOfGroup > 3) then exit;
        end;
      46:
        begin
          inc(ipNoOfGroups);
          Val(Copy(sIPAddress, ipPosition - ipLengthOfGroup, ipLengthOfGroup), ipGroupNum, Code);
          if ((ipNoOfGroups > 3) or (ipLengthOfGroup = 0)) or (ipGroupNum > 255) then exit;
          ipLengthOfGroup := 0;
        end;
      else
        exit;
    end;
  Val(Copy(sIPAddress, ipPosition - ipLengthOfGroup, ipLengthOfGroup), ipGroupNum, Code);
  IsIPAddress := (ipNoOfGroups = 3) and (ipLengthOfGroup > 0) and (ipGroupNum < 256);
end;

end.
